/* -------------------------------------------------------------------------
   ------------------------------------------------------------------------- */
#ifndef IVR_DEFS_H
#define IVR_DEFS_H

#include <winsock2.h>
#include <windows.h>

#ifdef __DLL__
#define MYLIBAPI __declspec(dllexport)
#else
#define MYLIBAPI __declspec(dllimport)
#endif

#include "gui_log.h"

//#define TFVERSION "Internal build"                 // default internal build number
#ifdef _M_X64
#define TFBITNESS "(64-bit)"    // adds to TFVERSION string
#else
#define TFBITNESS "(32-bit)"    // adds to TFVERSION string
#endif
#define TFVERSION "Build 2014.03.07 "TFBITNESS   // release build number
                                                 // You must also change the version number
                                                 // properties of the TFServer.EXE project
                                                 // in Borland Project Manager
#define FOREVER                (-1L)
#define MAX_DIGIT_BUFFER_SIZE   49

#define AUDIO_POSITION_START       1
#define AUDIO_POSITION_END         2
#define AUDIO_POSITION_FORWARD     3
#define AUDIO_POSITION_BACKWARD    4

#define AUDIO_SPEED_INCREASE       1
#define AUDIO_SPEED_DECREASE       2

#define AUDIO_VOLUME_NORMAL        1
#define AUDIO_VOLUME_INCREASE      2

// If no TCP/IP port is specified, this port will be used
#define DEFAULT_IVR_PORT  5050

// Registry key where TeleFlow applications store registry keys
#define TELEFLOW_REG_KEY  "SOFTWARE\\enGenic"

// Maximum length for Application Name
#define TELEFLOW_APP_NAME_MAX 30

// Maximum length for .TAM Name
#define TELEFLOW_TAM_NAME_MAX 30

// Maximum length for .TAP Name
#define TELEFLOW_TAP_NAME_MAX 30

// Maximum length for step Name
#define TELEFLOW_STEP_NAME_MAX 30

// Maximum length for step Name
#define TELEFLOW_SYS_INFO_MAX 40

// TeleFlow file/data format field delimiters
#define  END_FIELD    '\001'
#define  END_RECORD   '\002'
#define  END_SUBFIELD '\003'
#define  END_SUBSECT  '\004'
#define  END_SECTION  '\032'
#define  END_FILE     '\032'

// Sound formats with historical values
// TF_WAV_8KHZ_8BIT_MULAW was TF_VOX_8KHZ_8BIT_MULAW
enum SOUND_FORMAT
{
  TF_BY_EXTENSION = 0,
  TF_WAV_8KHZ_16BIT = 2,
  TF_VCE_24 = 4,
  TF_VOX = 9,
  TF_WAV_8KHZ_8BIT_MULAW = 10,
  TF_WAV_8KHZ_16BIT_G610 = 11,
  TF_WAV_8KHZ_8BIT_ALAW = 12
};

enum callMode { newLine, existingLine };

enum IV_STATUS
{
   IVR_SUCCESS          = 0,
   IVR_FAIL             = 1,
   IVR_FATAL            = 2,
   IVR_TIMEOUT          = 3,
   IVR_HANGUP           = 4,
   IVR_SHUTDOWN         = 5,
   IVR_ENDPROC          = 6,
   IVR_APPCALL          = 7,
   IVR_GOTO             = 8,
   IVR_APPGOTO          = 9,
   IVR_RELOAD           = 10,
   IVR_BUSY             = 11,
   IVR_GENERIC_TIMEOUT  = 12,
   IVR_NOTSUPPORTED     = 13,
   IVR_TRUE             = 14,
   IVR_FALSE            = 15,
   IVR_THRESHOLD        = 16,
   IVR_GENERIC_EVENT    = 17,
   IVR_NO_VOICE         = 18,
   IVR_SILENCE_TIMEOUT  = 19,
   IVR_NO_RESOURCE      = 20
};

enum VOICE_STATUS { VS_TTONLY, VS_VOICEONLY, VS_BOTH };

// These must be in the same order that they are loaded.
enum LINE_STATUS { lsEmpty, lsNormal, lsWarning, lsCrashed, lsNotRunning };

/* -------------------------------------------------------------------------
   Name:        CLIENT_MSG

   Purpose:     This structure is used to send messages to the TeleFlow
                Monitor application so it can monitor the health of the
                TeleFlow Server.

   Notes:       * *** 'bChanged' was boolean but the server and client
                  used different sizes.
                * *** 'status' was LINE_STATUS but the server and client
                  used different sizes.
   ------------------------------------------------------------------------- */
typedef struct
{
   union {
      GUILog* ivLog;
      DWORD64 padding;       // Force the ptr to align on 64-bit boundary
   };
   long  msgNo;              // Msg sequence number (range: 1 - 1,000,000).
   long  appID;              // Unique application ID.
   char  appNm[TELEFLOW_APP_NAME_MAX + 1];	   // Application name.
   char  appFile[TELEFLOW_TAP_NAME_MAX + 1];	   // .TAP file name
   long  lineNo;             // Line number if phone off-hook.
   long  stepNo;             // Current step number.
   char  currentTAMName[TELEFLOW_TAM_NAME_MAX + 1]; // Current procedure.
   char  stepName[TELEFLOW_STEP_NAME_MAX + 1];  // Step name (e.g. "Wait For Call").
   char  stepData[TELEFLOW_SYS_INFO_MAX + 1];       // Extra info provided by @SYS_DATA system var
   char  status;             // Application status.
   int   license;         // JSH 2003-07-24: 1, 0, -1
   int restartCnt;           // Number of times restarted.
   int restartMax;        // Maximum restart count.
} CLIENT_MSG;

// Need to maintain current size and structure of 'CLIENT_MSG' for legacy Monitor or Server programs
// 'EXPANDED_CLIENT_MSG' is used to provide more information to Monitor thread to support new functionality
typedef struct
{
  CLIENT_MSG client_msg;
  char  calledNumber[MAX_DIGIT_BUFFER_SIZE + 1];   // Called number (DNIS)
  char  callingNumber[MAX_DIGIT_BUFFER_SIZE + 1];  // Calling number (ANI or CLID)
} EXPANDED_CLIENT_MSG;

#define MAX_CLIENTS  500

#endif
